@@ -329,11 +329,20 @@ class DatasetImporter:
 
     Attributes
     ----------
-    dataset : :obj:`aspecd.dataset.Dataset`
+    dataset : :class:`aspecd.dataset.Dataset`
         dataset to import data and metadata into
-    source : string
+
+    source : :class:`str`
         specifier of the source the data and metadata will be read from
 
+    parameters : :class:`dict`
+        Additional parameters to control import options.
+
+        Useful in case of, *e.g.*, CSV importers where the user may want to
+        set things such as the delimiter
+
+        .. versionadded:: 0.2
+
     Raises
     ------
     aspecd.io.MissingDatasetError
@@ -344,6 +353,7 @@ class DatasetImporter:
     def __init__(self, source=None):
         self.source = source
         self.dataset = None
+        self.parameters = dict()
 
     def import_into(self, dataset=None):
         """Perform the actual import into the given dataset.
@@ -441,6 +451,15 @@ class DatasetImporterFactory:
     implementation in the rare case of having only one single type of data,
     but provides a sensible starting point for own developments.
 
+
+    Attributes
+    ----------
+    source : :class:`str`
+        Source of the dataset to be loaded.
+
+        Gets set by calling the method :meth:`get_importer` with the
+        ``source`` parameter.
+
     Raises
     ------
     aspecd.io.MissingSourceError
@@ -448,7 +467,10 @@ class DatasetImporterFactory:
 
     """
 
-    def get_importer(self, source=''):
+    def __init__(self):
+        self.source = None
+
+    def get_importer(self, source='', importer='', parameters=None):
         """
         Return importer object for dataset specified by its source.
 
@@ -456,6 +478,12 @@ class DatasetImporterFactory:
         case should be implemented in the non-public method
         :meth:`_get_importer` in any package based on the ASpecD framework.
 
+        If no importer gets returned by the method :meth:`_get_importer`,
+        the ASpecD-interal importers will be checked for matching the file
+        type. Thus, you can overwrite the behaviour of any filetype
+        supported natively by the ASpecD framework, but retain compatibility
+        to the ASpecD-specific file types.
+
         .. note::
             Currently, only filenames/paths are supported, and if ``source``
             does not start with the file separator, the absolute path to the
@@ -469,6 +497,20 @@ class DatasetImporterFactory:
 
             May be a filename or path, a URL/URI, a LOI, or similar
 
+        importer : :class:`str`
+            Name of the importer to use for importing the dataset
+
+            Default: ''
+
+            .. versionadded:: 0.2
+
+        parameters : :class:`dict`
+            Additional parameters for controlling the import
+
+            Default: None
+
+            .. versionadded:: 0.2
+
         Returns
         -------
         importer : :class:`aspecd.io.DatasetImporter`
@@ -483,21 +525,52 @@ class DatasetImporterFactory:
         if not source:
             raise aspecd.exceptions.MissingSourceError(
                 'A source is required to return an appropriate importer')
-        return self._get_importer(source)
+        self.source = source
+        if not self.source.startswith(os.pathsep):
+            self.source = os.path.join(os.path.abspath(os.curdir), self.source)
+        if importer:
+            package_name = aspecd.utils.package_name(self)
+            full_class_name = '.'.join([package_name, 'io', importer])
+            importer = aspecd.utils.object_from_class_name(full_class_name)
+            importer.source = self.source
+        if not importer:
+            importer = self._get_importer()
+        if not importer:
+            importer = self._get_aspecd_importer()
+        if parameters:
+            importer.parameters = parameters
+        return importer
 
     # noinspection PyMethodMayBeStatic
     # pylint: disable=no-self-use
-    def _get_importer(self, source):
-        if not source.startswith(os.pathsep):
-            source = os.path.join(os.path.abspath(os.curdir), source)
-        _, file_extension = os.path.splitext(source)
+    def _get_importer(self):
+        """Choose appropriate importer for a dataset.
+
+        Every package inheriting from the ASpecD framework should implement
+        this method. Note that in case you do not handle a filetype and
+        hence return no importer, the default ASpecD importer will be
+        checked for matching the given source. Thus, you can overwrite the
+        behaviour of any filetype supported natively by the ASpecD
+        framework, but retain compatibility to the ASpecD-specific file types.
+
+        Returns
+        -------
+        importer : :class:`aspecd.io.DatasetImporter`
+            Importer for the specific file type
+
+        """
+        importer = None
+        return importer
+
+    def _get_aspecd_importer(self):
+        _, file_extension = os.path.splitext(self.source)
         if file_extension == '.adf':
-            return AdfImporter(source=source)
+            return AdfImporter(source=self.source)
         if file_extension == '.asdf':
-            return AsdfImporter(source=source)
+            return AsdfImporter(source=self.source)
         if file_extension == '.txt':
-            return TxtImporter(source=source)
-        return DatasetImporter(source=source)
+            return TxtImporter(source=self.source)
+        return DatasetImporter(source=self.source)
 
 
 class DatasetExporter:
@@ -1014,6 +1087,7 @@ class AsdfImporter(DatasetImporter):
 
 
 class TxtImporter(DatasetImporter):
+    # noinspection PyUnresolvedReferences
     """
     Dataset importer for importing from plain text files (TXT).
 
@@ -1034,14 +1108,24 @@ class TxtImporter(DatasetImporter):
     interpreted as the *x* axis. In all other cases, data will be read as is
     and no axes values explicitly written.
 
+
+    Attributes
+    ----------
+    parameters : :class:`dict`
+        Parameters controlling the import
+
+        skiprows : :class:`int`
+            Number of rows to skip in text file (*e.g.*, header lines)
+
     """
 
     def __init__(self, source=None):
         super().__init__(source=source)
         self.extension = '.txt'
+        self.parameters["skiprows"] = 0
 
     def _import(self):
-        data = np.loadtxt(self.source)
+        data = np.loadtxt(self.source, **self.parameters)
         if len(np.shape(data)) > 1 and np.shape(data)[1] == 2:
             self.dataset.data.axes[0].values = data[:, 0]
             data = data[:, 1]
